@@ -6,15 +6,15 @@
 #' as a length two vector with (U, a) to define the PC-prior
 #' parameters such that P(range<U)=a and P(sigma>U)=a, respectively.
 #' See Fuglstad et. al. (2019) <DOI: 10.1080/01621459.2017.1415907>.
-#' If a=0 then U is taken to be the fixed value of the parameter.
-#' @param constr logical to indicate if the integral of the field
-#' over the domain is to be constrained to zero. Default value is FALSE.
-#' @param debug integer indicating the debug level.
-#' Will be used as logical by INLA.
-#' @param useINLAprecomp logical indicating if is to be used
-#' shared object pre-compiled by INLA. Not considered if
-#' libpath is provided.
-#' @param libpath string to the shared object. Default is NULL.
+#' If a=0 or a=NA, then U is taken to be the fixed
+#' value of the parameter.
+#' @param constr logical, default is FALSE, to indicate if the
+#' integral of the field over the domain is to be constrained to zero.
+#' @param ... additional arguments that will be passed on to
+#' [INLAtools::cgenericBuilder()], such as:
+#'  `debug` : logical/integer, default is FALSE/0.
+#'  `useINLAprecomp` logical, default is TRUE, indicating if it is to
+#' be used the shared object pre-compiled by INLA.
 #' @note
 #' This is the stationary case of [INLA::inla.spde2.pcmatern()]
 #' with slight change on the marginal variance when the domain is
@@ -26,7 +26,7 @@
 #'
 #' Finn Lindgren, Haakon Bakka, David Bolin, Elias Krainski and Håvard Rue (2024).
 #' A diffusion-based spatio-temporal extension of Gaussian Matérn fields.
-#' [SORT 48 (1), 3-66](https://www.idescat.cat/sort/sort481/48.1.1.Lindgren-etal.pdf)
+#' [SORT vol.  48, no. 1, pp. 3-66](https://raco.cat/index.php/SORT/article/view/428665)
 #' <doi: 10.57645/20.8080.02.13>
 #' @return objects to be used in the f() formula term in INLA.
 #' @importFrom fmesher fm_manifold
@@ -36,9 +36,12 @@ cgeneric_sspde <-
            alpha,
            control.priors,
            constr = FALSE,
-           debug = FALSE,
-           useINLAprecomp = TRUE,
-           libpath = NULL) {
+           ...) {
+
+    dotArgs <- list(...)
+    if(!any(names(dotArgs)=="debug")) {
+      dotArgs$debug <- FALSE
+    }
 
     stopifnot(fm_manifold(mesh, c("S", "R")))
     Rmanifold <- fm_manifold(mesh, "R") + 0L
@@ -65,37 +68,31 @@ cgeneric_sspde <-
     stopifnot(control.priors$prange[2]<1)
     stopifnot(control.priors$psigma[2]<1)
 
-    INLAversion <- check_package_version_and_load(
-      pkg = "INLA",
+    INLAversion <- INLAtools::packageCheck(
+      name = "INLA",
       minimum_version = "25.03.11",
       quietly = TRUE
     )
-    if (is.null(libpath)) {
-      if(length(useINLAprecomp)>1) {
-        warning("length(useINLAprecomp)>1, first taken!")
-        useINLAprecomp <- useINLAprecomp[1]
-      }
-      stopifnot(is.logical(useINLAprecomp))
-      if(is.na(INLAversion) & useINLAprecomp) {
-        stop("Update INLA or try `useINLAprecomp = FALSE`!")
-      }
-      if (useINLAprecomp) {
-        libpath <- INLA::inla.external.lib("INLAspacetime")
-      } else {
-        libpath <- system.file("libs", package = "INLAspacetime")
-        if (Sys.info()["sysname"] == "Windows") {
-          libpath <- file.path(libpath, "INLAspacetime.dll")
-        } else {
-          libpath <- file.path(libpath, "INLAspacetime.so")
-        }
-      }
+    if(!any(names(dotArgs)=="useINLAprecomp")) {
+      dotArgs$useINLAprecomp <- TRUE
     }
+    if(length(dotArgs$useINLAprecomp)>1) {
+      warning("length(useINLAprecomp)>1, first taken!")
+      dotArgs$useINLAprecomp <- dotArgs$useINLAprecomp[1]
+    }
+    stopifnot(is.logical(dotArgs$useINLAprecomp))
+    libpath <- INLAtools::cgeneric_shlib(
+      package = "INLAspacetime",
+      useINLAprecomp = dotArgs$useINLAprecomp
+    )
     stopifnot(file.exists(libpath))
 
-    if(alpha!=2) stop("Only 'alpha = 2' is supported for now.")
+    if(alpha!=2) {
+      stop("Only 'alpha = 2' is supported for now.")
+    }
     nu.s <- alpha - dimension / 2
 
-    if (debug) {
+    if (dotArgs$debug) {
       print(c(alpha = alpha, nu.s = nu.s))
     }
 
@@ -111,34 +108,37 @@ cgeneric_sspde <-
     if (Rmanifold) {
       cc[2] <- lgamma(alpha - (dimension * 0.5)) -
         lgamma(alpha) -(dimension * 0.5) * log(4 * pi)
-      if (debug) {
+      if (dotArgs$debug) {
         cat("R manifold, cc[2] = ", cc[2], "\n")
       }
     } else {
       ## c2 part depending on gamma to be completed in C
       cc[2] <- -log(4 * pi) ## (S1???)
-      if (debug) {
+      if (dotArgs$debug) {
         cat("S manifold, cc[2] = ", cc[2], "\n")
       }
     }
-    if (debug) {
+    if (dotArgs$debug) {
       print(c(cc = cc))
     }
 
     fem <- fmesher::fm_fem(mesh, order = 2)
     stopifnot((n <- nrow(fem$g1))>0)
-    lmats <- upperPadding(
+    lmats <- INLAtools::upperPadding(
       fem[c("c0", "g1", "g2")],
-      relative = FALSE)
+      relative = FALSE,
+      unique = TRUE,
+      na.rm = TRUE,
+      zeros.rm = TRUE)
     stopifnot(n == nrow(lmats$graph))
 
     the_model <- do.call(
-      "inla.cgeneric.define",
-      list(
+      what = INLAtools::cgenericBuilder,
+      args = list(
         model = "inla_cgeneric_sspde",
         shlib = libpath,
         n = as.integer(n),
-        debug = as.integer(debug),
+        debug = as.integer(dotArgs$debug),
         Rmanifold = as.integer(Rmanifold),
         dimension = as.integer(dimension),
         alpha = as.integer(alpha),
@@ -158,5 +158,16 @@ cgeneric_sspde <-
     the_model$"mesh" <- mesh
     the_model$"fem" <- fem
 
+    the_model$mapper <- NULL
+    if(requireNamespace("inlabru")) {
+      if(!is.na(INLAtools::packageCheck(
+        name = "inlabru",
+        minimum_version = "2.12.0.9021",
+        quietly = TRUE
+      ))) {
+        the_model$mapper <- inlabru::bru_mapper(mesh)
+      }
+    }
+
     return(the_model)
   }
