@@ -10,25 +10,27 @@
 #' with length two containing (U, a) to define the
 #' corresponding PC-prior such that, respectively,
 #' P(range.spatial<U)=a, P(range.temporal<U)=a or P(sigma>U)=a.
-#' If a=0 then U is taken to be the fixed value of the parameter.
-#' @param constr logical to indicate if the integral of the field
-#' over the domain is to be constrained to zero. Default value is FALSE.
-#' @param debug integer indicating the verbose level.
+#' If a=0 or a=NA, then U is taken to be the fixed
+#' value of the parameter.
+#' @param constr logical, default is FALSE, to indicate if the
+#' integral of the field over the domain is to be constrained to zero.
+#' @param debug integer, default is zero, indicating the verbose level.
 #' Will be used as logical by INLA.
-#' @param useINLAprecomp logical indicating if is to be used
-#' shared object pre-compiled by INLA. Not considered if
-#' libpath is provided.
-#' @param libpath string to the shared object. Default is NULL.
+#' @param useINLAprecomp logical, default is TRUE, indicating if it is to
+#' be used the shared object pre-compiled by INLA.
+#' This is not considered if 'libpath' is provided.
+#' @param libpath string, default is NULL, with the path to the shared object.
 #' @details
-#' The matrices of the kronecker product in Theorem 4.1 of
-#' Lindgren et. al. (2024) are computed with the
-#' [stModel.matrices] and the parameters are as Eq (19-21),
-#' but parametrized in log scale.
+#' This function compute the matrices for computing the precision matrix.
+#' These are each one of the Kronecker products in Theorem 4.1 of
+#' Lindgren et. al. (2024) computed with the
+#' [stModel.matrices] and the parameters are as in Eq (19-21).
+#' We use the log of these parameters internally.
 #' @return objects to be used in the f() formula term in INLA.
 #' @references
 #' Finn Lindgren, Haakon Bakka, David Bolin, Elias Krainski and Håvard Rue (2024).
 #' A diffusion-based spatio-temporal extension of Gaussian Matérn fields.
-#' [SORT 48 (1), 3-66](https://www.idescat.cat/sort/sort481/48.1.1.Lindgren-etal.pdf)
+#' [SORT vol.  48, no. 1, pp. 3-66](https://raco.cat/index.php/SORT/article/view/428665)
 #' <doi: 10.57645/20.8080.02.13>
 #' @export
 #' @importFrom fmesher fm_manifold
@@ -48,6 +50,16 @@ stModel.define <-
     stopifnot(length(control.priors$prs)==2)
     stopifnot(length(control.priors$psigma)==2)
 
+    if(is.na(control.priors$prt[2])) {
+      control.priors$prt[2] <- 0
+    }
+    if(is.na(control.priors$prs[2])) {
+      control.priors$prs[2] <- 0
+    }
+    if(is.na(control.priors$psigma[2])) {
+      control.priors$psigma[2] <- 0
+    }
+
     stopifnot(control.priors$prt[1]>0)
     stopifnot(control.priors$prs[1]>0)
     stopifnot(control.priors$psigma[1]>0)
@@ -60,8 +72,8 @@ stModel.define <-
     stopifnot(control.priors$prs[2]<1)
     stopifnot(control.priors$psigma[2]<1)
 
-    INLAversion <- check_package_version_and_load(
-      pkg = "INLA",
+    INLAversion <- INLAtools::packageCheck(
+      name = "INLA",
       minimum_version = "23.08.16",
       quietly = TRUE
     )
@@ -133,7 +145,8 @@ stModel.define <-
     jmm <- pmatch(paste0("M", 1:nm), names(mm))
     stopifnot(length(jmm[complete.cases(jmm)]) == nm)
 
-    lmats <- upperPadding(mm[jmm], relative = FALSE)
+    lmats <- INLAtools::upperPadding(
+      mm[jmm], relative = FALSE)
     stopifnot(n == nrow(lmats$graph))
 
     args0 <- list(
@@ -170,11 +183,25 @@ stModel.define <-
     }
     # Prepend specialised model class identifier, for bru_mapper use:
     class(the_model) <- c("stModel_cgeneric", class(the_model))
+
+    the_model$mapper <- NULL
+    if(requireNamespace("inlabru")) {
+      ## (construct the mapper already here, but that would
+      ## require loading inlabru even when it's not going to be used)
+      if(!is.na(INLAtools::packageCheck(
+        name = "inlabru",
+        minimum_version = "2.12.0.9021",
+        quietly = TRUE
+      ))) {
+        the_model$mapper <- inlabru::bm_multi(
+          list(space = inlabru::bru_mapper(smesh),
+               time = inlabru::bru_mapper(tmesh))
+        )
+      }
+    }
     # Add objects needed by bru_get_mapper.stModel_cgeneric:
-    # (alternatively, construct the mapper already here, but that would
-    # require loading inlabru even when it's not going to be used)
     the_model[["smesh"]] <- smesh
     the_model[["tmesh"]] <- tmesh
 
-    the_model
+    return(the_model)
   }
