@@ -25,20 +25,6 @@
  *        Thuwal 23955-6900, Saudi Arabia
  */
 
-#ifndef __CGENERIC_DEFS_H__
-#define __CGENERIC_DEFS_H__
-
-#undef __BEGIN_DECLS
-#undef __END_DECLS
-#ifdef __cplusplus
-#define __BEGIN_DECLS extern "C" {
-#define __END_DECLS }
-#else
-#define __BEGIN_DECLS					       /* empty */
-#define __END_DECLS					       /* empty */
-#endif
-
-__BEGIN_DECLS
 #include <stddef.h>
 #include <stdio.h>
 #include <assert.h>
@@ -53,11 +39,13 @@ __BEGIN_DECLS
 #define pow2(x) SQR(x)
 #define pow3(x) (pow2(x)*(x))
 #define pow4(x) (pow2(x)*pow2(x))
+#if !defined(iszero)
 #ifdef __SUPPORT_SNAN__
 #define iszero(x) (fpclassify(x) == FP_ZERO)
 #else
 #define iszero(x) (((__typeof(x))(x)) == 0)
 #endif
+#endif
 #if __GNUC__ > 7
 typedef size_t fortran_charlen_t;
 #else
@@ -70,13 +58,11 @@ void dgemv_(char *trans, int *M, int *N, double *alpha, double *A, int *LDA, dou
 double ddot_(int *N, double *DX, int *INCX, double *DY, int *INCY);
 
 inla_cgeneric_func_tp inla_cgeneric_ar2ss_model;
-inla_cgeneric_func_tp inla_cgeneric_sstspde;
+inla_cgeneric_func_tp inla_cgeneric_sspde;
 inla_cgeneric_func_tp inla_cgeneric_barrier;
+inla_cgeneric_func_tp inla_cgeneric_sstspde;
 
 double pclogrange(double logrange, double lamda, int dim);
 double pclogsigma(double logsigma, double lamda);
 void CSphere_gamma_alpha(double *lnGamma2, double *dalpha, double *cska);
-void ar2cov(int *n, int *k, double *a1, double *a2, double *r);
-
-__END_DECLS
-#endif
+void ar2covk(int *n, int *k, double *a1, double *a2, double *r);
